# -*- coding: UTF-8 -*-
from setuphelpers import *
import time

# Installation procedure: https://firefox-source-docs.mozilla.org/browser/installer/windows/installer/FullConfig.html
# Configuration procedure: https://support.mozilla.org/kb/customizing-firefox-using-policiesjson

dist_dir = "distribution"
dist_path = makepath(programfiles, "Mozilla Firefox", dist_dir)
ext_dir = "extensions"
ext_path = makepath(dist_path, ext_dir)
policies_file = "policies.json"
policies_path = makepath(dist_path, policies_file)
list_pre_installed_lang = ["fr", "en-GB", "es-ES", "de", "it"]  # Reminder: 'en-US' will be native


def install():
    bin_name = glob.glob("Firefox_Setup_*.exe")[0]
    app_uninstallkey = "Mozilla Firefox %s (%s en-US)" % (control.get_software_version(), control.architecture)

    # Uninstalling others versions
    for uninstall in installed_softwares(name="Mozilla Firefox"):
        if not control.architecture in uninstall["name"] or "ESR" in uninstall["name"]:
            print("Removing: %s" % (uninstall["name"]))
            killalltasks(control.get_impacted_process_list())
            run(uninstall_cmd(uninstall["key"]))
            time.sleep(15)  # Required for Firefox

    # Installing the software
    install_exe_if_needed(
        bin_name,
        silentflags="/S /PreventRebootRequired=false /TaskbarShortcut=false /DesktopShortcut=false /StartMenuShortcut=true /MaintenanceService=false /RegisterDefaultAgent=false /RemoveDistributionDir=false /OptionalExtensions=false",
        key=app_uninstallkey,
        min_version=control.get_software_version(),
    )

    # Making sure that Mozilla Maintenance Service is not installed
    for uninstall in installed_softwares(name="Mozilla Maintenance Service"):
        print("Removing: %s" % (uninstall["name"]))
        run(uninstall_cmd(uninstall["key"]))

    # Removing policies from registry since it bypass the policies.json file (source: https://support.mozilla.org/bm/questions/1236197)
    ffox_policies_reg_path = r"SOFTWARE\Policies\Mozilla\Firefox"
    if reg_key_exists(HKEY_LOCAL_MACHINE, ffox_policies_reg_path):
        registry_deletekey(HKEY_LOCAL_MACHINE, ffox_policies_reg_path, "", force=True)

    # Adding distribution folder for language packs, dictionaries, extensions and configuration
    if isdir(dist_path):
        remove_tree(dist_path)
    mkdirs(dist_path)
    filecopyto(makepath(basedir, policies_file), dist_path)
    copytree2(makepath(basedir, ext_dir), ext_path)

    # Changing default language
    data = json_load_file(policies_path)
    my_lang = get_language()
    for select_lang in list_pre_installed_lang:
        if my_lang in select_lang:
            if select_lang == "en-GB":
                select_lang = "en-US"
            default_lang = {"RequestedLocales": ["%s" % select_lang]}
    data["policies"].update(default_lang)
    json_write_file(policies_path, data, indent=2)
